@@ -4,15 +4,12 @@
 import copy
 from typing import Dict, List
 
-import imantics
 import numpy as np
 
 from sahi.utils.coco import CocoAnnotation, CocoPrediction
-from sahi.utils.cv import (
-    get_bbox_from_bool_mask,
-    get_bool_mask_from_coco_segmentation,
-    get_coco_segmentation_from_bool_mask,
-)
+from sahi.utils.cv import (get_bbox_from_bool_mask,
+                           get_bool_mask_from_coco_segmentation,
+                           get_coco_segmentation_from_bool_mask)
 from sahi.utils.shapely import ShapelyAnnotation
 
 
@@ -567,6 +564,13 @@ class ObjectAnnotation:
         """
         Returns imantics.annotation.Annotation representation of ObjectAnnotation.
         """
+        try:
+            import imantics
+        except ImportError:
+            raise ImportError(
+                'Please run "pip install -U imantics" '
+                'to install imantics first for imantics conversion.')
+
         imantics_category = imantics.Category(
             id=self.category.id, name=self.category.name
         )
