@@ -7,18 +7,13 @@ from typing import Dict, List
 
 import cv2
 import numpy as np
-import skimage.io
 from tqdm import tqdm
 
 from sahi.utils.coco import Coco, CocoAnnotation, CocoImage, create_coco_dict
 from sahi.utils.cv import read_large_image
 from sahi.utils.file import create_dir, load_json, save_json
-from sahi.utils.shapely import (
-    ShapelyAnnotation,
-    get_bbox_from_shapely,
-    get_shapely_box,
-    get_shapely_multipolygon,
-)
+from sahi.utils.shapely import (ShapelyAnnotation, get_bbox_from_shapely,
+                                get_shapely_box, get_shapely_multipolygon)
 
 
 def slice_coco_annotations_by_box(
@@ -342,6 +337,12 @@ def slice_image(
                     verboseprint("outpath:", outpath)
                     # if large image, convert to bgr prior to saving
                     if not use_cv2:
+                        try:
+                            import skimage.io
+                        except ImportError:
+                            raise ImportError(
+                                'Please run "pip install -U scikit-image" '
+                                'to install scikit-image first for large image handling.')
                         skimage.io.imsave(outpath, window_c)
                     else:
                         window_c = cv2.cvtColor(window_c, cv2.COLOR_RGB2BGR)
